@@ -30,7 +30,7 @@ import (
 )
 
 const (
-	version             = "0.5.4"
+	version             = "0.5.5"
 	nsBOSH              = "urn:xmpp:alt-connections:xbosh"
 	nsC2SdTLS           = "urn:xmpp:alt-connections:tls"
 	nsC2SQuic           = "urn:xmpp:alt-connections:quic"
@@ -92,6 +92,8 @@ func main() {
 	flagVersion := getopt.BoolLong("version", 0, "Show version information.")
 	flagFallback := getopt.BoolLong("fallback", 'f', "Check fallback (Standard ports on A/AAAA records)"+
 		" if no SRV records are provided.")
+	flagForceFallback := getopt.BoolLong("force-fallback", 0, "Check fallback (Standard ports on A/AAAA records)"+
+		" even if SRV records are provided.")
 	flagTimeout := getopt.IntLong("timeout", 0, 60, "Connection timeout in seconds.")
 	flagResolver := getopt.StringLong("resolver", 0, "", "Custom resolver e.g. \"1.1.1.1\" for common DNS"+
 		" or \"5.1.66.255#dot.ffmuc.net\" for usage with \"--dot\".")
@@ -195,26 +197,46 @@ func main() {
 	}
 
 	if *flagClient {
+		var fallback bool
 		clientRecords, err := c.LookupClient(serverASCII)
 		if err != nil && len(clientRecords) == 0 {
 			fmt.Println(err)
 			if *flagFallback && *flagTest {
+				fallback = true
 				fmt.Println("Trying fallback ports.")
 				fmt.Println()
-				clientRecords = []xmppsrv.SRV{
-					{
-						Type:   "xmpp-client",
-						Target: server[0],
-						Port:   5222,
-					},
+			}
+		}
+		if *flagForceFallback && !fallback && *flagTest {
+			if len(clientRecords) > 0 {
+				var standardPort bool
+				for _, r := range clientRecords {
+					if r.Type == "xmpp-client" &&
+						(r.Target == server[0] ||
+							r.Target == server[0]+".") &&
+						r.Port == 5222 {
+						standardPort = true
+					}
+				}
+				if !standardPort {
+					fallback = true
 				}
 			}
 		}
+		if fallback {
+			cr := xmppsrv.SRV{
+				Type:   "xmpp-client",
+				Target: server[0],
+				Port:   5222,
+			}
+			clientRecords = append(clientRecords, cr)
+		}
 		checkRecord(clientRecords, *flagVerbose, *flagV4, *flagV6, *flagTest,
 			server[0], &tlsConfig, timeout)
 	}
 
 	if *flagServer {
+		var fallback bool
 		if *flagClient {
 			fmt.Println()
 		}
@@ -222,17 +244,35 @@ func main() {
 		if err != nil && len(serverRecords) == 0 {
 			fmt.Println(err)
 			if *flagFallback && *flagTest {
+				fallback = true
 				fmt.Println("Trying fallback ports.")
 				fmt.Println()
-				serverRecords = []xmppsrv.SRV{
-					{
-						Type:   "xmpp-server",
-						Target: serverASCII,
-						Port:   5269,
-					},
+			}
+		}
+		if *flagForceFallback && !fallback && *flagTest {
+			if len(serverRecords) > 0 {
+				var standardPort bool
+				for _, r := range serverRecords {
+					if r.Type == "xmpp-server" &&
+						(r.Target == serverASCII ||
+							r.Target == serverASCII+".") &&
+						r.Port == 5269 {
+						standardPort = true
+					}
+				}
+				if !standardPort {
+					fallback = true
 				}
 			}
 		}
+		if fallback {
+			sr := xmppsrv.SRV{
+				Type:   "xmpp-server",
+				Target: serverASCII,
+				Port:   5269,
+			}
+			serverRecords = append(serverRecords, sr)
+		}
 		checkRecord(serverRecords, *flagVerbose, *flagV4, *flagV6, *flagTest,
 			server[0], &tlsConfig, timeout)
 	}
@@ -1086,9 +1126,10 @@ func checkCertExpiry(c *tls.Conn) {
 	now := time.Now()
 	switch {
 	case time.Until(expiry).Hours() < 336:
-		fmt.Printf("%s[OK]%s", colorYellow, colorReset)
+		fmt.Printf("[%sOK%s]", colorYellow, colorReset)
 		printTLSVersion(c.ConnectionState().Version)
-		fmt.Printf(" (Cert expires in %d days.)\n", int(time.Until(expiry).Hours())/24)
+		fmt.Printf(" (Cert expires in %d days at %s)\n",
+			int(time.Until(expiry).Hours())/24, expiry.Truncate(time.Second).String())
 	case now.Before(expiry) && now.After(start):
 		fmt.Print(statusOK)
 		printTLSVersion(c.ConnectionState().Version)
